This is an easy to use Python library which allows you to make your terminal outputs more colorful and therefore easier to read and understand.

It currently only works with Python3

The creator and maintainer is Engr. Mubashir Hussain (mubashir)

GitHub: https://github.com/mubashir6u/hueText

PyPi: https://pypi.org/project/hueText/

Contributing
If you've found a bug or a typo, feel free to open an Issue on GitHub. Already have a solution? Make a Pull request and I'll take a look at your changes. Please make sure a similar Issue/Pull request doesn't already exist.

Installation
This library is hosted on pypi.org. You can install it with pip:

pip install hueText

Usage
To use this library, you first have to import it:

import hueText
To print colored text do the following:

print(hueText.color("GREEN","green"))           # 'GREEN' will be green
print(hueText.color("Red","red"))               # 'Red' will be red

You can also use special 'pre-fixes':

This library was published under the GNU General Public License. For more information take a look at the LICENSE file.